@@ -1,4 +1,7 @@
+from hashlib import md5
+
 import numpy as np
+from numpy.random import RandomState
 
 
 def is_symmetrical(arr):
@@ -18,6 +21,19 @@ def min_max(it):
     return min_, max_
 
 
+def get_random_state(state=None):
+    if isinstance(state, RandomState):
+        return state
+    if state is None:
+        return RandomState()
+    try:
+        seed = int(state)
+    except ValueError:
+        # use hash digest when seed is a (non-numerical) string
+        seed = int(md5(state.encode('utf-8')).hexdigest(), 16) & 0xffffffff
+    return RandomState(seed)
+
+
 def set_suffix(filename, suffix):
     s = suffix.strip(' .')
     if filename.lower().endswith('.'+s.lower()):
