@@ -4,14 +4,13 @@ from functools   import cached_property
 
 import numpy as np
 from numba  import njit
-from seedpy import get_random_state
 
-from .misc import all_bitvectors, bitvector_from_string, bitvector_to_string, set_suffix
+from .misc import all_bitvectors, bitvector_from_string, bitvector_to_string, get_random_state, set_suffix
 
 
 class BinarySample:
 
-    def __init__(self, *, counts: dict[str, int]=None, raw: np.ndarray=None):
+    def __init__(self, *, counts=None, raw: np.ndarray=None):
         if counts is not None:
             self.counts = counts
         elif raw is not None:
@@ -56,12 +55,12 @@ class BinarySample:
         return n
 
     @cached_property
-    def shots(self):
+    def size(self):
         return sum(self.counts.values())
 
     @cached_property
     def raw(self):
-        X = np.empty((self.shots, self.n))
+        X = np.empty((self.size, self.n))
         pointer = 0
         for x, k in self.counts.items():
             X[pointer:pointer+k, :] = np.tile(bitvector_from_string(x), (k, 1))
@@ -78,16 +77,15 @@ class BinarySample:
         xs = set(self.counts.keys())
         xs.update(other.counts.keys())
         xs = list(xs)
-        p1 = np.asarray([self.counts.get(x, 0) for x in xs], dtype=np.float64)/self.shots
-        p2 = np.asarray([other.counts.get(x, 0) for x in xs], dtype=np.float64)/other.shots
+        p1 = np.asarray([self.counts.get(x, 0) for x in xs], dtype=np.float64)/self.size
+        p2 = np.asarray([other.counts.get(x, 0) for x in xs], dtype=np.float64)/other.size
         return np.linalg.norm(np.sqrt(p1)-np.sqrt(p2))/np.sqrt(2.0)
 
-    def subsample(self, shots: int, random_state=None):
+    def subsample(self, size: int, random_state=None):
         npr = get_random_state(random_state)
-
         xs = list(sorted(self.counts.keys())) # sort for reproducibility
         cumcs = np.cumsum(np.asarray([self.counts[x] for x in xs]))
-        mask = npr.permutation(self.shots) < shots
+        mask = npr.permutation(self.size) < size
         counts = dict()
         for u, v, x in zip(np.r_[0, cumcs], cumcs, xs):
             c = mask[u:v].sum()
@@ -95,16 +93,13 @@ class BinarySample:
                 counts[x] = c
         return BinarySample(counts=counts)
 
+    def most_frequent(self):
+        return max(self.counts, key=self.counts.get)
 
-def generate_num_flips(λ=1.0, random_state=None):
-    npr = get_random_state(random_state)
-    flip_list = []
-    while True:
-        if flip_list:
-            yield flip_list.pop()
-        else:
-            ks = npr.poisson(1, size=100)
-            flip_list.extend(ks[ks>0])
+    def empirical_prob(self, x):
+        c = self.counts.get(x, 0)
+        return c/self.size
+        
 
 
 def full(qubo, samples: int=1, temp=1.0, random_state=None):
